==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScatterLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBaseDescription } from "./ScatterBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ScatterLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeriesDescription, _super);
    function ScatterLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.ez = null;
        return _this;
    }
    ScatterLineSeriesDescription.prototype.get_type = function () {
        return "ScatterLineSeries";
    };
    Object.defineProperty(ScatterLineSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.ez;
        },
        set: function (a) {
            this.ez = a;
            this.e("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    ScatterLineSeriesDescription.$t = markType(ScatterLineSeriesDescription, 'ScatterLineSeriesDescription', ScatterBaseDescription.$);
    return ScatterLineSeriesDescription;
}(ScatterBaseDescription));
export { ScatterLineSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/ScatterLineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBaseDescription } from "./ScatterBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ScatterLineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeriesDescription, _super);
    function ScatterLineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.g9 = null;
        return _this;
    }
    ScatterLineSeriesDescription.prototype.get_type = function () {
        return "ScatterLineSeries";
    };
    Object.defineProperty(ScatterLineSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.g9;
        },
        set: function (a) {
            this.g9 = a;
            this.g("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    ScatterLineSeriesDescription.$t = markType(ScatterLineSeriesDescription, 'ScatterLineSeriesDescription', ScatterBaseDescription.$);
    return ScatterLineSeriesDescription;
}(ScatterBaseDescription));
export { ScatterLineSeriesDescription };
